@@ -1,15 +1,12 @@
 package Moose::Meta::Attribute::Native::Trait::Bool;
+BEGIN {
+  $Moose::Meta::Attribute::Native::Trait::Bool::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Moose::Meta::Attribute::Native::Trait::Bool::VERSION = '2.0401';
+}
 use Moose::Role;
 
-our $VERSION = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
-use Moose::Meta::Method::Accessor::Native::Bool::not;
-use Moose::Meta::Method::Accessor::Native::Bool::set;
-use Moose::Meta::Method::Accessor::Native::Bool::toggle;
-use Moose::Meta::Method::Accessor::Native::Bool::unset;
-
 with 'Moose::Meta::Attribute::Native::Trait';
 
 sub _default_is  { 'rw' }
@@ -19,12 +16,20 @@ no Moose::Role;
 
 1;
 
+# ABSTRACT: Helper trait for Bool attributes
+
+
+
 =pod
 
 =head1 NAME
 
 Moose::Meta::Attribute::Native::Trait::Bool - Helper trait for Bool attributes
 
+=head1 VERSION
+
+version 2.0401
+
 =head1 SYNOPSIS
 
   package Room;
@@ -91,15 +96,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Jason May
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
