@@ -1,18 +1,12 @@
 package Moose::Meta::Attribute::Native::Trait::Number;
+BEGIN {
+  $Moose::Meta::Attribute::Native::Trait::Number::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Moose::Meta::Attribute::Native::Trait::Number::VERSION = '2.0401';
+}
 use Moose::Role;
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
-use Moose::Meta::Method::Accessor::Native::Number::abs;
-use Moose::Meta::Method::Accessor::Native::Number::add;
-use Moose::Meta::Method::Accessor::Native::Number::div;
-use Moose::Meta::Method::Accessor::Native::Number::mod;
-use Moose::Meta::Method::Accessor::Native::Number::mul;
-use Moose::Meta::Method::Accessor::Native::Number::set;
-use Moose::Meta::Method::Accessor::Native::Number::sub;
-
 with 'Moose::Meta::Attribute::Native::Trait';
 
 sub _helper_type { 'Num' }
@@ -21,12 +15,20 @@ no Moose::Role;
 
 1;
 
+# ABSTRACT: Helper trait for Num attributes
+
+
+
 =pod
 
 =head1 NAME
 
 Moose::Meta::Attribute::Native::Trait::Number - Helper trait for Num attributes
 
+=head1 VERSION
+
+version 2.0401
+
 =head1 SYNOPSIS
 
   package Real;
@@ -102,15 +104,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Robert Boone
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
