@@ -1,18 +1,26 @@
 
 package Moose::Meta::Instance;
+BEGIN {
+  $Moose::Meta::Instance::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Moose::Meta::Instance::VERSION = '2.0401';
+}
 
 use strict;
 use warnings;
 
-our $VERSION   = '0.82';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
+use Class::MOP::MiniTrait;
 
 use base "Class::MOP::Instance";
 
+Class::MOP::MiniTrait::apply(__PACKAGE__, 'Moose::Meta::Object::Trait');
+
 1;
 
-__END__
+# ABSTRACT: The Moose Instance metaclass
+
+
 
 =pod
 
@@ -20,6 +28,10 @@ __END__
 
 Moose::Meta::Instance - The Moose Instance metaclass
 
+=head1 VERSION
+
+version 2.0401
+
 =head1 SYNOPSIS
 
     # nothing to see here
@@ -43,23 +55,21 @@ C<Moose::Meta::Instance> is a subclass of L<Class::MOP::Instance>.
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
-
-Yuval Kogman E<lt>nothingmuch@woobling.comE<gt>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2009 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
