@@ -1,12 +1,14 @@
 package Moose::Meta::Method;
+BEGIN {
+  $Moose::Meta::Method::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Moose::Meta::Method::VERSION = '2.0401';
+}
 
 use strict;
 use warnings;
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Class::MOP::MiniTrait;
 
 use base 'Class::MOP::Method';
@@ -15,6 +17,7 @@ Class::MOP::MiniTrait::apply(__PACKAGE__, 'Moose::Meta::Object::Trait');
 
 sub _error_thrower {
     my $self = shift;
+    require Moose::Meta::Class;
     ( ref $self && $self->associated_metaclass ) || "Moose::Meta::Class";
 }
 
@@ -30,12 +33,29 @@ sub throw_error {
 
 sub _inline_throw_error {
     my ( $self, $msg, $args ) = @_;
-    "\$meta->throw_error($msg" . ($args ? ", $args" : "") . ")"; # FIXME makes deparsing *REALLY* hard
+
+    my $inv = $self->_error_thrower;
+    # XXX ugh
+    $inv = 'Moose::Meta::Class' unless $inv->can('_inline_throw_error');
+
+    # XXX ugh ugh UGH
+    my $class = $self->associated_metaclass;
+    if ($class) {
+        my $class_name = B::perlstring($class->name);
+        my $meth_name = B::perlstring($self->name);
+        $args = 'method => Class::MOP::class_of(' . $class_name . ')'
+              . '->find_method_by_name(' . $meth_name . '), '
+              . (defined $args ? $args : '');
+    }
+
+    return $inv->_inline_throw_error($msg, $args)
 }
 
 1;
 
-__END__
+# ABSTRACT: A Moose Method metaclass
+
+
 
 =pod
 
@@ -43,6 +63,10 @@ __END__
 
 Moose::Meta::Method - A Moose Method metaclass
 
+=head1 VERSION
+
+version 2.0401
+
 =head1 DESCRIPTION
 
 This class is a subclass of L<Class::MOP::Method> that provides
@@ -61,15 +85,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
