@@ -1,12 +1,14 @@
 package Moose::Meta::Method::Accessor::Native::Number::abs;
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Number::abs::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Moose::Meta::Method::Accessor::Native::Number::abs::VERSION = '2.0401';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Moose::Role;
 
 with 'Moose::Meta::Method::Accessor::Native::Writer' => {
@@ -18,18 +20,20 @@ with 'Moose::Meta::Method::Accessor::Native::Writer' => {
     ]
     };
 
-sub _maximum_arguments {0}
+sub _maximum_arguments { 0 }
 
 sub _potential_value {
-    my ( $self, $slot_access ) = @_;
+    my $self = shift;
+    my ($slot_access) = @_;
 
-    return "abs($slot_access)";
+    return 'abs(' . $slot_access . ')';
 }
 
 sub _inline_optimized_set_new_value {
-    my ( $self, $inv, $new, $slot_access ) = @_;
+    my $self = shift;
+    my ($inv, $new, $slot_access) = @_;
 
-    return "$slot_access = abs($slot_access)";
+    return $slot_access . ' = abs(' . $slot_access . ');';
 }
 
 no Moose::Role;
