@@ -1,4 +1,10 @@
 package Moose::Meta::Role::Application::RoleSummation;
+BEGIN {
+  $Moose::Meta::Role::Application::RoleSummation::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Moose::Meta::Role::Application::RoleSummation::VERSION = '2.0401';
+}
 
 use strict;
 use warnings;
@@ -8,15 +14,12 @@ use Scalar::Util 'blessed';
 
 use Moose::Meta::Role::Composite;
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use base 'Moose::Meta::Role::Application';
 
 __PACKAGE__->meta->add_attribute('role_params' => (
     reader  => 'role_params',
-    default => sub { {} }
+    default => sub { {} },
+    Class::MOP::_definition_context(),
 ));
 
 sub get_exclusions_for_role {
@@ -138,7 +141,7 @@ sub apply_attributes {
                 "We have encountered an attribute conflict with '$name' "
                     . "during role composition. "
                     . " This attribute is defined in both $role1 and $role2."
-                    . " This is fatal error and cannot be disambiguated." );
+                    . " This is a fatal error and cannot be disambiguated." );
         }
 
         $seen{$name} = $attr;
@@ -254,7 +257,9 @@ sub apply_method_modifiers {
 
 1;
 
-__END__
+# ABSTRACT: Combine two or more roles
+
+
 
 =pod
 
@@ -262,6 +267,10 @@ __END__
 
 Moose::Meta::Role::Application::RoleSummation - Combine two or more roles
 
+=head1 VERSION
+
+version 2.0401
+
 =head1 DESCRIPTION
 
 Summation composes two traits, forming the union of non-conflicting
@@ -311,16 +320,18 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
+
