@@ -1,20 +1,24 @@
 package Moose::Meta::Role::Application::ToInstance;
+BEGIN {
+  $Moose::Meta::Role::Application::ToInstance::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Moose::Meta::Role::Application::ToInstance::VERSION = '2.0401';
+}
 
 use strict;
 use warnings;
 use metaclass;
 
 use Scalar::Util 'blessed';
-
-our $VERSION   = '1.09';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
+use List::MoreUtils 'all';
 
 use base 'Moose::Meta::Role::Application';
 
 __PACKAGE__->meta->add_attribute('rebless_params' => (
     reader  => 'rebless_params',
-    default => sub { {} }
+    default => sub { {} },
+    Class::MOP::_definition_context(),
 ));
 
 sub apply {
@@ -31,7 +35,7 @@ sub apply {
     my $class = $obj_meta->create_anon_class(
         superclasses => [ blessed($object) ],
         roles => [ $role, keys(%$args) ? ($args) : () ],
-        cache => 1,
+        cache => (all { $_ eq '-alias' || $_ eq '-excludes' } keys %$args),
     );
 
     $class->rebless_instance( $object, %{ $self->rebless_params } );
@@ -39,7 +43,9 @@ sub apply {
 
 1;
 
-__END__
+# ABSTRACT: Compose a role into an instance
+
+
 
 =pod
 
@@ -47,6 +53,10 @@ __END__
 
 Moose::Meta::Role::Application::ToInstance - Compose a role into an instance
 
+=head1 VERSION
+
+version 2.0401
+
 =head1 DESCRIPTION
 
 =head2 METHODS
@@ -69,16 +79,18 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
+
