@@ -1,5 +1,11 @@
 
 package Moose::Meta::TypeCoercion::Union;
+BEGIN {
+  $Moose::Meta::TypeCoercion::Union::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Moose::Meta::TypeCoercion::Union::VERSION = '2.0401';
+}
 
 use strict;
 use warnings;
@@ -7,10 +13,6 @@ use metaclass;
 
 use Scalar::Util 'blessed';
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use base 'Moose::Meta::TypeCoercion';
 
 sub compile_type_coercion {
@@ -45,7 +47,9 @@ sub add_type_coercions {
 
 1;
 
-__END__
+# ABSTRACT: The Moose Type Coercion metaclass for Unions
+
+
 
 =pod
 
@@ -53,6 +57,10 @@ __END__
 
 Moose::Meta::TypeCoercion::Union - The Moose Type Coercion metaclass for Unions
 
+=head1 VERSION
+
+version 2.0401
+
 =head1 DESCRIPTION
 
 This is a subclass of L<Moose::Meta::TypeCoercion> that is used for
@@ -83,15 +91,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
