@@ -1,5 +1,11 @@
 
 package Moose::Meta::TypeConstraint::Registry;
+BEGIN {
+  $Moose::Meta::TypeConstraint::Registry::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Moose::Meta::TypeConstraint::Registry::VERSION = '2.0401';
+}
 
 use strict;
 use warnings;
@@ -7,21 +13,19 @@ use metaclass;
 
 use Scalar::Util 'blessed';
 
-our $VERSION   = '1.09';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use base 'Class::MOP::Object';
 
 __PACKAGE__->meta->add_attribute('parent_registry' => (
     reader    => 'get_parent_registry',
     writer    => 'set_parent_registry',
     predicate => 'has_parent_registry',
+    Class::MOP::_definition_context(),
 ));
 
 __PACKAGE__->meta->add_attribute('type_constraints' => (
     reader  => 'type_constraints',
-    default => sub { {} }
+    default => sub { {} },
+    Class::MOP::_definition_context(),
 ));
 
 sub new {
@@ -63,7 +67,8 @@ sub find_type_constraint {
 
 1;
 
-__END__
+# ABSTRACT: registry for type constraints
+
 
 
 =pod
@@ -72,6 +77,10 @@ __END__
 
 Moose::Meta::TypeConstraint::Registry - registry for type constraints
 
+=head1 VERSION
+
+version 2.0401
+
 =head1 DESCRIPTION
 
 This class is a registry that maps type constraint names to
@@ -148,15 +157,18 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
+
