@@ -1,16 +1,19 @@
 package Moose::Role;
+BEGIN {
+  $Moose::Role::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Moose::Role::VERSION = '2.0401';
+}
 use strict;
 use warnings;
 
 use Scalar::Util 'blessed';
 use Carp         'croak';
+use Class::Load  'is_class_loaded';
 
 use Sub::Exporter;
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Moose       ();
 use Moose::Util ();
 
@@ -110,6 +113,9 @@ sub init_meta {
     my $metaclass = $args{metaclass} || "Moose::Meta::Role";
     my $meta_name = exists $args{meta_name} ? $args{meta_name} : 'meta';
 
+    Moose->throw_error("The Metaclass $metaclass must be loaded. (Perhaps you forgot to 'use $metaclass'?)")
+        unless is_class_loaded($metaclass);
+
     Moose->throw_error("The Metaclass $metaclass must be a subclass of Moose::Meta::Role.")
         unless $metaclass->isa('Moose::Meta::Role');
 
@@ -151,7 +157,9 @@ sub init_meta {
 
 1;
 
-__END__
+# ABSTRACT: The Moose Role
+
+
 
 =pod
 
@@ -159,6 +167,10 @@ __END__
 
 Moose::Role - The Moose Role
 
+=head1 VERSION
+
+version 2.0401
+
 =head1 SYNOPSIS
 
   package Eq;
@@ -183,6 +195,23 @@ Moose::Role - The Moose Role
       $self->as_float == $other->as_float;
   }
 
+  # ... and also
+
+  package Comparator;
+  use Moose;
+
+  has compare_to => (
+      is      => 'ro',
+      does    => 'Eq',
+      handles => 'Eq',
+  );
+
+  # ... which allows
+
+  my $currency1 = Currency->new(...);
+  my $currency2 = Currency->new(...);
+  Comparator->new(compare_to => $currency1)->equal($currency2);
+
 =head1 DESCRIPTION
 
 The concept of roles is documented in L<Moose::Manual::Roles>. This document
@@ -220,22 +249,10 @@ Moose::Role offers a way to remove the keywords it exports, through the
 C<unimport> method. You simply have to say C<no Moose::Role> at the bottom of
 your code for this to work.
 
-=head2 B<< Moose::Role->init_meta(for_class => $role, metaclass => $metaclass) >>
-
-The C<init_meta> method sets up the metaclass object for the role
-specified by C<for_class>. It also injects a a C<meta> accessor into
-the role so you can get at this object.
-
-The default metaclass is L<Moose::Meta::Role>. You can specify an
-alternate metaclass with the C<metaclass> parameter.
-
 =head1 METACLASS
 
-When you use Moose::Role, you can specify which metaclass to use:
-
-    use Moose::Role -metaclass => 'My::Meta::Role';
-
-You can also specify traits which will be applied to your role metaclass:
+When you use Moose::Role, you can specify traits which will be applied to your
+role metaclass:
 
     use Moose::Role -traits => 'My::Trait';
 
@@ -255,11 +272,12 @@ L<Moose::Util> 'apply_all_roles' or the role's metaclass:
 
 Doing this creates a new, mutable, anonymous subclass, applies the role to that,
 and reblesses. In a debugger, for example, you will see class names of the
-form C< Class::MOP::Class::__ANON__::SERIAL::6 >, which means that doing a 'ref'
-on your instance may not return what you expect. See L<Moose::Object> for 'DOES'.
+form C< Moose::Meta::Class::__ANON__::SERIAL::6 >, which means that doing a
+'ref' on your instance may not return what you expect. See L<Moose::Object> for
+'DOES'.
 
-Additional params may be added to the new instance by providing 'rebless_params'.
-See L<Moose::Meta::Role::Application::ToInstance>.
+Additional params may be added to the new instance by providing
+'rebless_params'. See L<Moose::Meta::Role::Application::ToInstance>.
 
 =head1 CAVEATS
 
@@ -295,17 +313,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
-
-Christian Hansen E<lt>chansen@cpan.orgE<gt>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
